@@ -20,6 +20,7 @@ library(ggdist)
 library(ggplot2)
 library(broom)
 library(modelr)
+library(distributional)
 
 theme_set(theme_ggdist())
 
@@ -56,7 +57,7 @@ m_ABC %>%
   tidy() %>%
   ggplot(aes(y = term)) +
   stat_dist_halfeye(
-    aes(dist = "student_t", arg1 = df.residual(m_ABC), arg2 = estimate, arg3 = std.error)
+    aes(dist = dist_student_t(df = df.residual(m_ABC), mu = estimate, sigma = std.error))
   )
 
 ## ----halfeye_with_data------------------------------------------------------------------------------------------------
@@ -65,7 +66,7 @@ ABC %>%
   augment(m_ABC, newdata = ., se_fit = TRUE) %>%
   ggplot(aes(y = condition)) +
   stat_dist_halfeye(
-    aes(dist = "student_t", arg1 = df.residual(m_ABC), arg2 = .fitted, arg3 = .se.fit), 
+    aes(dist = dist_student_t(df = df.residual(m_ABC), mu = .fitted, sigma = .se.fit)), 
     scale = .5
   ) +
   # we'll add the data back in too (scale = .5 above adjusts the halfeye height so
@@ -78,7 +79,7 @@ ABC %>%
   augment(m_ABC, newdata = ., se_fit = TRUE) %>%
   ggplot(aes(y = condition)) +
   stat_dist_gradientinterval(
-    aes(dist = "student_t", arg1 = df.residual(m_ABC), arg2 = .fitted, arg3 = .se.fit), 
+    aes(dist = dist_student_t(df = df.residual(m_ABC), mu = .fitted, sigma = .se.fit)), 
     scale = .5
   )
 
@@ -88,7 +89,7 @@ ABC %>%
   augment(m_ABC, newdata = ., se_fit = TRUE) %>%
   ggplot(aes(y = condition)) +
   stat_dist_ccdfinterval(
-    aes(dist = "student_t", arg1 = df.residual(m_ABC), arg2 = .fitted, arg3 = .se.fit)
+    aes(dist = dist_student_t(df = df.residual(m_ABC), mu = .fitted, sigma = .se.fit))
   )
 
 ## ----dotplot----------------------------------------------------------------------------------------------------------
@@ -97,8 +98,8 @@ ABC %>%
   augment(m_ABC, newdata = ., se_fit = TRUE) %>%
   ggplot(aes(y = condition)) +
   stat_dist_dots(
-    quantiles = 100,
-    aes(dist = "student_t", arg1 = df.residual(m_ABC), arg2 = .fitted, arg3 = .se.fit)
+    aes(dist = dist_student_t(df = df.residual(m_ABC), mu = .fitted, sigma = .se.fit)),
+    quantiles = 100
   )
 
 ## ----m_mpg------------------------------------------------------------------------------------------------------------
@@ -111,7 +112,7 @@ mtcars %>%
   augment(m_mpg, newdata = ., se_fit = TRUE) %>%
   ggplot(aes(x = hp, fill = ordered(cyl), color = ordered(cyl))) +
   stat_dist_lineribbon(
-    aes(dist = "student_t", arg1 = df.residual(m_mpg), arg2 = .fitted, arg3 = .se.fit), 
+    aes(dist = dist_student_t(df = df.residual(m_mpg), mu = .fitted, sigma = .se.fit)),
     alpha = 1/4
   ) +
   geom_point(aes(y = mpg), data = mtcars) +
@@ -124,6 +125,27 @@ mtcars %>%
     y = "mpg"
   )
 
+## ----lineribbon_lightened---------------------------------------------------------------------------------------------
+mtcars %>%
+  group_by(cyl) %>%
+  data_grid(hp = seq_range(hp, n = 101)) %>%
+  augment(m_mpg, newdata = ., se_fit = TRUE) %>%
+  ggplot(aes(x = hp, color = ordered(cyl))) +
+  stat_dist_lineribbon(aes(
+    dist = dist_student_t(df = df.residual(m_mpg), mu = .fitted, sigma = .se.fit),
+    fill = ordered(cyl),
+    fill_ramp = stat(level)
+  )) +
+  geom_point(aes(y = mpg), data = mtcars) +
+  
+  scale_fill_brewer(palette = "Set2") +
+  scale_color_brewer(palette = "Dark2") +
+  labs(
+    color = "cyl",
+    fill = "cyl",
+    y = "mpg"
+  )
+
 ## ----reset_options, include=FALSE---------------------------------------------
 options(.old_options)
 
