@@ -16,8 +16,8 @@ RankCorr_u_tau = RankCorr_u_tau %>%
   group_by(i)
 
 test_that("horizontal grouped pointintervals work", {
-  skip_if_not_installed("vdiffr")
-  skip_if_not_installed("svglite")
+  skip_if_no_vdiffr()
+
 
   vdiffr::expect_doppelganger("grouped pointintervals (h)",
     RankCorr_u_tau %>%
@@ -54,8 +54,8 @@ test_that("horizontal grouped pointintervals work", {
 })
 
 test_that("grouped pointintervals work", {
-  skip_if_not_installed("vdiffr")
-  skip_if_not_installed("svglite")
+  skip_if_no_vdiffr()
+
 
   forward_plot = RankCorr_u_tau %>%
     mean_qi(.width = c(.66, .95)) %>%
@@ -69,7 +69,7 @@ test_that("grouped pointintervals work", {
     ggplot(aes(x = i, y = u_tau, ymin = .lower, ymax = .upper, interval_size = forcats::fct_rev(ordered(.width))), point_size = 3) +
     geom_pointinterval()
 
-  vdiffr::expect_doppelganger("grouped pointintervals with interval_size and legend", forward_plot)
+  vdiffr::expect_doppelganger("grouped, with interval_size and legend", forward_plot)
 
   stat_forward_plot = RankCorr_u_tau %>%
     ggplot(aes(x = i, y = u_tau)) +
@@ -80,8 +80,8 @@ test_that("grouped pointintervals work", {
 })
 
 test_that("orientation detection on pointintervals works", {
-  skip_if_not_installed("vdiffr")
-  skip_if_not_installed("svglite")
+  skip_if_no_vdiffr()
+
 
   p = data.frame(
     v = c(1,2),
@@ -90,27 +90,27 @@ test_that("orientation detection on pointintervals works", {
     g = c("a", "b")
   ) %>% ggplot()
 
-  vdiffr::expect_doppelganger("vertical pointinterval orientation detection",
+  vdiffr::expect_doppelganger("vertical, orientation detection",
     p + geom_pointinterval(aes(x = g, y = v, ymin = l, ymax = u), orientation = NA)
   )
 
-  vdiffr::expect_doppelganger("horizontal pointinterval orientation detection",
+  vdiffr::expect_doppelganger("horizontal, orientation detection",
     p + geom_pointinterval(aes(y = g, x = v, xmin = l, xmax = u), orientation = NA)
   )
 
-  vdiffr::expect_doppelganger("vertical pointinterval orientation detection plus dodge",
+  vdiffr::expect_doppelganger("vertical, orientation detection plus dodge",
     p + geom_pointinterval(aes(color = g, y = v, ymin = l, ymax = u), orientation = NA, position = "dodge")
   )
 
-  vdiffr::expect_doppelganger("horizontal pointinterval orientation detection, dodge",
+  vdiffr::expect_doppelganger("horizontal, orientation detection, dodge",
     p + geom_pointinterval(aes(color = g, x = v, xmin = l, xmax = u), orientation = NA, position = "dodge")
   )
 
 })
 
 test_that("missing data is handled correctly", {
-  skip_if_not_installed("vdiffr")
-  skip_if_not_installed("svglite")
+  skip_if_no_vdiffr()
+
 
   p = data.frame(
     x = c(1,NA,1),
